==> librenms-25.6.0v0.tgz: librenms/LibreNMS/Util/Proxy.php <==
<?php

/*
 * Proxy.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    LibreNMS
 * @link       http://librenms.org
 * @copyright  2021 Tony Murray
 * @author     Tony Murray <murraytony@gmail.com>
 */

namespace LibreNMS\Util;

use LibreNMS\Config;

class Proxy
{
    public static function http(): string
    {
        // use local_only to avoid CVE-2016-5385
        $http_proxy = getenv('http_proxy', local_only: true) ?: getenv('HTTP_PROXY', local_only: true) ?: Config::get('http_proxy', '');

        return $http_proxy;
    }

    public static function https(): string
    {
        // use local_only to avoid CVE-2016-5385
        return getenv('https_proxy', local_only: true) ?: getenv('HTTPS_PROXY', local_only: true) ?: Config::get('https_proxy', '');
    }

    public static function ignore(): array
    {
        // use local_only to avoid CVE-2016-5385
        $no_proxy = getenv('no_proxy', local_only: true) ?: getenv('NO_PROXY', local_only: true) ?: Config::get('no_proxy', '');

        if ($no_proxy == '') {
            return [];
        }

        return explode(',', str_replace(' ', '', $no_proxy));
    }
}

==> librenms-25.11.0v0.tgz: librenms/LibreNMS/Util/Proxy.php <==
<?php

/*
 * Proxy.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    LibreNMS
 * @link       http://librenms.org
 * @copyright  2021 Tony Murray
 * @author     Tony Murray <murraytony@gmail.com>
 */

namespace LibreNMS\Util;

use App\Facades\LibrenmsConfig;

class Proxy
{
    public static function http(): string
    {
        // use local_only to avoid CVE-2016-5385
        $http_proxy = getenv('http_proxy', local_only: true) ?: getenv('HTTP_PROXY', local_only: true) ?: LibrenmsConfig::get('http_proxy', '');

        return $http_proxy;
    }

    public static function https(): string
    {
        // use local_only to avoid CVE-2016-5385
        return getenv('https_proxy', local_only: true) ?: getenv('HTTPS_PROXY', local_only: true) ?: LibrenmsConfig::get('https_proxy', '');
    }

    public static function ignore(): array
    {
        // use local_only to avoid CVE-2016-5385
        $no_proxy = getenv('no_proxy', local_only: true) ?: getenv('NO_PROXY', local_only: true) ?: LibrenmsConfig::get('no_proxy', '');

        if ($no_proxy == '') {
            return [];
        }

        return explode(',', str_replace(' ', '', $no_proxy));
    }
}
